@@ -6,7 +6,6 @@
 #include "amici/model.h"
 #include "amici/misc.h"
 #include "amici/forwardproblem.h"
-
 #include <vector>
 
 namespace amici {
@@ -33,7 +32,7 @@ namespace amici {
  * NOTE: multidimensional arrays are stored in row-major order
  * (FORTRAN-style)
  */
-class ReturnData {
+class ReturnData: public ModelDimensions {
   public:
     /**
      * @brief default constructor
@@ -42,36 +41,24 @@ class ReturnData {
 
     /**
      * @brief ReturnData
-     * @param ts see amici::Model::ts
-     * @param np see amici::Model::np
-     * @param nk see amici::Model::nk
-     * @param nx see amici::Model::nx_rdata
-     * @param nx_solver see amici::Model::nx_solver
-     * @param nxtrue see amici::Model::nxtrue_rdata
-     * @param nx_solver_reinit see amici::Model::nx_solver_reinit
-     * @param ny see amici::Model::ny
-     * @param nytrue see amici::Model::nytrue
-     * @param nz see amici::Model::nz
-     * @param nztrue see amici::Model::nztrue
-     * @param ne see amici::Model::ne
-     * @param nJ see amici::Model::nJ
-     * @param nplist see amici::Model::nplist
-     * @param nmaxevent see amici::Model::nmaxevent
-     * @param nt see amici::Model::nt
+     * @param ts see amici::SimulationParameters::ts
+     * @param model_dimensions Model dimensions
+     * @param nplist see amici::ModelDimensions::nplist
+     * @param nmaxevent see amici::ModelDimensions::nmaxevent
+     * @param nt see amici::ModelDimensions::nt
      * @param newton_maxsteps see amici::Solver::newton_maxsteps
-     * @param nw see amici::Model::nw
-     * @param pscale see amici::Model::pscale
-     * @param o2mode see amici::Model::o2mode
+     * @param pscale see amici::SimulationParameters::pscale
+     * @param o2mode see amici::SimulationParameters::o2mode
      * @param sensi see amici::Solver::sensi
      * @param sensi_meth see amici::Solver::sensi_meth
      * @param rdrm see amici::Solver::rdata_reporting
      * @param quadratic_llh whether model defines a quadratic nllh and computing res, sres and
      * FIM makes sense
      */
-    ReturnData(std::vector<realtype> ts, int np, int nk, int nx, int nx_solver,
-               int nxtrue, int nx_solver_reinit, int ny, int nytrue, int nz, int nztrue, int ne,
-               int nJ, int nplist, int nmaxevent, int nt, int newton_maxsteps,
-               int nw,
+    ReturnData(std::vector<realtype> ts,
+               ModelDimensions const& model_dimensions,
+               int nplist, int nmaxevent, int nt,
+               int newton_maxsteps,
                std::vector<ParameterScaling> pscale, SecondOrderMode o2mode,
                SensitivityOrder sensi, SensitivityMethod sensi_meth,
                RDataReporting rdrm, bool quadratic_llh);
@@ -104,127 +91,122 @@ class ReturnData {
                                   Model &model, Solver const &solver,
                                   ExpData const *edata);
 
-    /** timepoints (dimension: nt) */
+    /**
+     * timepoints (shape `nt`)
+     */
     std::vector<realtype> ts;
 
-    /** time derivative (dimension: nx) */
+    /** time derivative (shape `nx`) */
     std::vector<realtype> xdot;
 
     /**
-     * Jacobian of differential equation right hand side (dimension: nx x nx,
-     * row-major)
+     * Jacobian of differential equation right hand side (shape `nx` x `nx`, row-major)
      */
     std::vector<realtype> J;
 
     /**
      * w data from the model (recurring terms in xdot, for imported SBML models
-     * from python, this contains the flux vector)
-     * (dimensions: nt x nw, row major)
+     * from python, this contains the flux vector) (shape `nt` x `nw`, row major)
      */
     std::vector<realtype> w;
 
-    /** event output (dimension: nmaxevent x nz, row-major) */
+    /** event output (shape `nmaxevent` x `nz`, row-major) */
     std::vector<realtype> z;
 
     /**
-     * event output sigma standard deviation (dimension: nmaxevent x nz,
-     * row-major)
+     * event output sigma standard deviation (shape `nmaxevent` x `nz`, row-major)
      */
     std::vector<realtype> sigmaz;
 
     /**
-     * parameter derivative of event output (dimension: nmaxevent x nz,
-     * row-major)
+     * parameter derivative of event output (shape `nmaxevent` x `nz`, row-major)
      */
     std::vector<realtype> sz;
 
     /**
-     * parameter derivative of event output standard deviation (dimension:
-     * nmaxevent x nz, row-major)
+     * parameter derivative of event output standard deviation (shape `nmaxevent` x `nz`, row-major)
      */
     std::vector<realtype> ssigmaz;
 
-    /** event trigger output (dimension: nmaxevent x nz, row-major)*/
+    /** event trigger output (shape `nmaxevent` x `nz`, row-major)*/
     std::vector<realtype> rz;
 
     /**
-     * parameter derivative of event trigger output (dimension: nmaxevent x nz
-     * x nplist, row-major)
+     * parameter derivative of event trigger output (shape `nmaxevent` x `nz` x `nplist`, row-major)
      */
     std::vector<realtype> srz;
 
     /**
-     * second order parameter derivative of event trigger output (dimension:
-     * nmaxevent x nztrue x nplist x nplist, row-major)
+     * second order parameter derivative of event trigger output (shape
+     * `nmaxevent` x `nztrue` x `nplist` x `nplist`, row-major)
      */
     std::vector<realtype> s2rz;
 
-    /** state (dimension: nt x nx, row-major) */
+    /** state (shape `nt` x `nx`, row-major) */
     std::vector<realtype> x;
 
     /**
-     * parameter derivative of state (dimension: nt x nplist x nx, row-major)
+     * parameter derivative of state (shape `nt` x `nplist` x `nx`, row-major)
      */
     std::vector<realtype> sx;
 
-    /** observable (dimension: nt x ny, row-major) */
+    /** observable (shape `nt` x `ny`, row-major) */
     std::vector<realtype> y;
 
-    /** observable standard deviation (dimension: nt x ny, row-major) */
+    /** observable standard deviation (shape `nt` x `ny`, row-major) */
     std::vector<realtype> sigmay;
 
     /**
-     * parameter derivative of observable (dimension: nt x nplist x ny,
+     * parameter derivative of observable (shape `nt` x `nplist` x `ny`,
      * row-major)
      */
     std::vector<realtype> sy;
 
     /**
-     * parameter derivative of observable standard deviation (dimension: nt x
-     * nplist x ny, row-major)
+     * parameter derivative of observable standard deviation (shape `nt` x `nplist` x `ny`, row-major)
      */
     std::vector<realtype> ssigmay;
 
-    /** observable (dimension: nt*ny, row-major) */
+    /** observable (shape `nt*ny`, row-major) */
     std::vector<realtype> res;
 
     /**
-     * parameter derivative of residual (dimension: nt*ny x nplist, row-major)
+     * parameter derivative of residual (shape `nt*ny` x `nplist`, row-major)
      */
     std::vector<realtype> sres;
 
-    /** fisher information matrix (dimension: nplist x nplist, row-major) */
+    /** fisher information matrix (shape `nplist` x `nplist`, row-major) */
     std::vector<realtype> FIM;
 
-    /** number of integration steps forward problem (dimension: nt) */
+    /** number of integration steps forward problem (shape `nt`) */
     std::vector<int> numsteps;
 
-    /** number of integration steps backward problem (dimension: nt) */
+    /** number of integration steps backward problem (shape `nt`) */
     std::vector<int> numstepsB;
 
-    /** number of right hand side evaluations forward problem (dimension: nt) */
+    /** number of right hand side evaluations forward problem (shape `nt`) */
     std::vector<int> numrhsevals;
 
-    /** number of right hand side evaluations backward problem (dimension: nt) */
+    /** number of right hand side evaluations backward problem (shape `nt`) */
     std::vector<int> numrhsevalsB;
 
-    /** number of error test failures forward problem (dimension: nt) */
+    /** number of error test failures forward problem (shape `nt`) */
     std::vector<int> numerrtestfails;
 
-    /** number of error test failures backward problem (dimension: nt) */
+    /** number of error test failures backward problem (shape `nt`) */
     std::vector<int> numerrtestfailsB;
 
     /**
-     * number of linear solver convergence failures forward problem (dimension:
-     * nt) */
+     * number of linear solver convergence failures forward problem (shape `nt`)
+     */
     std::vector<int> numnonlinsolvconvfails;
 
     /**
-     * number of linear solver convergence failures backward problem (dimension:
-     * nt) */
+     * number of linear solver convergence failures backward problem (shape `nt`)
+     */
     std::vector<int> numnonlinsolvconvfailsB;
 
-    /** employed order forward problem (dimension: nt) */
+    /** employed order forward problem (shape `nt`) */
     std::vector<int> order;
 
     /** computation time of forward solve [ms] */
@@ -262,7 +244,7 @@ class ReturnData {
     /**
      * number of linear steps by Newton step for steady state problem. this
      * will only be filled for iterative solvers (preequilibration)
-     * (length = newton_maxsteps * 2)
+     * (shape `newton_maxsteps * 2`)
      */
     std::vector<int> preeq_numlinsteps;
 
@@ -274,14 +256,14 @@ class ReturnData {
 
     /**
      * number of Newton steps for steady state problem (preequilibration)
-     * [newton, simulation, newton] (length = 3) (postequilibration)
+     * [newton, simulation, newton] (shape `3`) (postequilibration)
      */
     std::vector<int> posteq_numsteps;
 
     /**
      * number of linear steps by Newton step for steady state problem. this
      * will only be filled for iterative solvers (postequilibration)
-     * (length = newton_maxsteps * 2)
+     * (shape `newton_maxsteps * 2`)
      */
     std::vector<int> posteq_numlinsteps;
 
@@ -313,18 +295,17 @@ class ReturnData {
      */
     realtype posteq_wrms = NAN;
 
-    /** initial state (dimension: nx) */
+    /** initial state (shape `nx`) */
     std::vector<realtype> x0;
 
-    /** preequilibration steady state found by Newton solver (dimension: nx) */
+    /** preequilibration steady state found by Newton solver (shape `nx`) */
     std::vector<realtype> x_ss;
 
-    /** initial sensitivities (dimension: nplist x nx, row-major) */
+    /** initial sensitivities (shape `nplist` x `nx`, row-major) */
     std::vector<realtype> sx0;
 
     /**
-     * preequilibration sensitivities found by Newton solver (dimension: nplist
-     * x nx, row-major)
+     * preequilibration sensitivities found by Newton solver (shape `nplist` x `nx`, row-major)
      */
     std::vector<realtype> sx_ss;
 
@@ -334,54 +315,26 @@ class ReturnData {
     /** chi2 value */
     realtype chi2 = 0.0;
 
-    /** parameter derivative of loglikelihood (dimension: nplist) */
+    /** parameter derivative of loglikelihood (shape `nplist`) */
     std::vector<realtype> sllh;
 
     /**
-     * second order parameter derivative of loglikelihood (dimension: (nJ-1) x
-     * nplist, row-major)
+     * second order parameter derivative of loglikelihood (shape `nJ-1` x `nplist`, row-major)
      */
     std::vector<realtype> s2llh;
 
     /** status code */
     int status = 0;
 
-    /** total number of model parameters */
-    int np{0};
-
-    /** number of fixed parameters */
-    int nk{0};
-
-    /** number of states */
+    /** number of states (alias nx_rdata, kept for backward compatibility) */
     int nx{0};
 
-    /** number of states with conservation laws applied */
-    int nx_solver{0};
-
-    /** number of states in the unaugmented system */
+    /**
+     * number of states in the unaugmented system
+     * (alias nxtrue_rdata, kept for backward compatibility)
+     */
     int nxtrue{0};
 
-    /** number of solver states to be reinitialized after preequilibration */
-    int nx_solver_reinit{0};
-
-    /** number of observables */
-    int ny{0};
-
-    /** number of observables in the unaugmented system */
-    int nytrue{0};
-
-    /** number of event outputs */
-    int nz{0};
-
-    /** number of event outputs in the unaugmented system */
-    int nztrue{0};
-
-    /** number of events */
-    int ne{0};
-
-    /** dimension of the augmented objective function for 2nd order ASA */
-    int nJ{0};
-
     /** number of parameter for which sensitivities were requested */
     int nplist{0};
 
@@ -391,9 +344,6 @@ class ReturnData {
     /** number of considered timepoints */
     int nt{0};
 
-    /** number of columns in w */
-    int nw{0};
-
     /** maximal number of newton iterations for steady state calculation */
     int newton_maxsteps{0};
 
@@ -445,7 +395,7 @@ class ReturnData {
     AmiVectorArray sx_rdata_;
 
     /** array of number of found roots for a certain event type
-     * (dimension: ne) */
+     * (shape `ne`) */
     std::vector<int> nroots_;
 
     /**
