@@ -34,6 +34,10 @@ static_assert(amici::AMICI_NORMAL == CV_NORMAL,
               "AMICI_NORMAL != CV_NORMAL");
 static_assert(amici::AMICI_ONE_STEP == CV_ONE_STEP,
               "AMICI_ONE_STEP != CV_ONE_STEP");
+static_assert(amici::AMICI_SINGULAR_JACOBIAN == SUNLS_PACKAGE_FAIL_UNREC,
+              "AMICI_SINGULAR_JACOBIAN != SUNLS_PACKAGE_FAIL_UNREC");
+static_assert(amici::AMICI_SINGULAR_JACOBIAN == SUNLS_PACKAGE_FAIL_UNREC,
+              "AMICI_SINGULAR_JACOBIAN != SUNLS_PACKAGE_FAIL_UNREC");
 static_assert(std::is_same<amici::realtype, realtype>::value,
               "Definition of realtype does not match");
 
